StructureLogger class

Central logger that fans out structured events to registered LogSinks.

Constructors

StructureLogger()
Creates an empty logger with no sinks registered yet.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addSink(LogSink sink) → void
Registers a sink that will receive every subsequent log event.
log(String message, {LogLevel level = LogLevel.info, Map<String, dynamic>? data}) Future<void>
Emits a structured log with an optional level and data properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeSink(LogSink sink) → void
Stops delivering log events to sink.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited